library("testthat")
test_package("MALDIquantForeign")
